"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = __importDefault(require("path"));
const fs_extra_1 = __importDefault(require("fs-extra"));
const diff2html_1 = require("diff2html");
const htmlTemplate = (diffHtml) => `<html>
<head>
  <title>GraphQL Schema Diff</title>
  <meta charset="utf-8" /> 
  <link rel="stylesheet" href="diff2html.css">
  <script src="diff2html.js"></script>
  <script src="diff2html-ui.js"></script>
  <style>
    html { box-sizing: border-box; }
    *,*:before,*:after { box-sizing: inherit; }
  </style>
</head>
<body>
  ${diffHtml}
</body>
</html>`;
async function createHtmlOutput(diff, options = {}) {
    const { outputDirectory = 'schemaDiff' } = options;
    const adjustedDiff = diff
        .replace(/(---\s.*)\sremoved/, '$1')
        .replace(/(\+\+\+\s.*)\sadded/, '$1');
    const diffHtml = diff2html_1.Diff2Html.getPrettyHtml(adjustedDiff, {
        inputFormat: 'diff',
        matching: 'lines',
        outputFormat: 'side-by-side',
        rawTemplates: {
            'tag-file-renamed': ''
        }
    });
    await fs_extra_1.default.ensureDir(outputDirectory);
    const diff2HtmlPath = path_1.default.dirname(require.resolve('diff2html/package.json'));
    await fs_extra_1.default.copy(path_1.default.join(diff2HtmlPath, 'dist'), outputDirectory);
    const htmlOutput = htmlTemplate(diffHtml);
    await fs_extra_1.default.writeFile(path_1.default.join(outputDirectory, 'index.html'), htmlOutput);
}
exports.createHtmlOutput = createHtmlOutput;
